@@ -10,13 +10,13 @@ import (
 	"errors"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"log"
 	"mime"
 	"mime/multipart"
 	"net"
 	"net/http"
 	"net/http/httptest"
+	"net/http/httputil"
 	"net/url"
 	"os"
 	"regexp"
@@ -320,7 +320,7 @@ func TestOutgoingFilter(t *testing.T) {
 		ResponseHeader: true,
 		ResponseBody:   true,
 	}
-	logger.SetOutput(ioutil.Discard)
+	logger.SetOutput(io.Discard)
 	logger.SetFilter(filteredURIs)
 	client := &http.Client{
 		Transport: logger.RoundTripper(newTransport()),
@@ -362,7 +362,7 @@ func TestOutgoingFilterPanicked(t *testing.T) {
 		ResponseHeader: true,
 		ResponseBody:   true,
 	}
-	logger.SetOutput(ioutil.Discard)
+	logger.SetOutput(io.Discard)
 	logger.SetFilter(func(req *http.Request) (bool, error) {
 		panic("evil panic")
 	})
@@ -1202,7 +1202,7 @@ func (h multipartHandler) ServeHTTP(w http.ResponseWriter, r *http.Request) {
 		t.Errorf("got size %d, wanted %d", header.Size, len(petition))
 	}
 
-	b, err := ioutil.ReadAll(file)
+	b, err := io.ReadAll(file)
 	if err != nil {
 		t.Errorf("server cannot read file sent over multipart: %v", err)
 	}
@@ -1250,6 +1250,57 @@ func TestOutgoingMultipartForm(t *testing.T) {
 	}
 }
 
+func TestOutgoingProxy(t *testing.T) {
+	t.Parallel()
+	ts := httptest.NewServer(&helloHandler{})
+	defer ts.Close()
+
+	proxyServer := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+		u, err := url.Parse(ts.URL)
+		if err != nil {
+			t.Fatal(err)
+		}
+		w.Header()["Date"] = nil
+		httputil.NewSingleHostReverseProxy(u).ServeHTTP(w, r)
+	}))
+	defer proxyServer.Close()
+
+	logger := &Logger{
+		RequestHeader:  true,
+		RequestBody:    true,
+		ResponseHeader: true,
+		ResponseBody:   true,
+	}
+	var buf bytes.Buffer
+	logger.SetOutput(&buf)
+	client := ts.Client()
+	transport := client.Transport.(*http.Transport)
+	proxyURL, err := url.Parse(proxyServer.URL)
+	if err != nil {
+		t.Errorf("cannot parse proxy URL: %v", err)
+
+	}
+	transport.Proxy = http.ProxyURL(proxyURL)
+	client.Transport = logger.RoundTripper(transport)
+
+	req, err := http.NewRequest(http.MethodGet, ts.URL, nil)
+	if err != nil {
+		t.Errorf("cannot create request: %v", err)
+	}
+	req.Host = "example.com" // overriding the Host header to send
+	req.Header.Add("User-Agent", "Robot/0.1 crawler@example.com")
+	resp, err := client.Do(req)
+	if err != nil {
+		t.Errorf("cannot connect to the server: %v", err)
+	}
+	defer resp.Body.Close()
+	want := fmt.Sprintf(golden(t.Name()), ts.URL, proxyServer.URL)
+	if got := buf.String(); !regexp.MustCompile(want).MatchString(got) {
+		t.Errorf("logged HTTP request %s; want %s", got, want)
+	}
+	testBody(t, resp.Body, []byte("Hello, world!"))
+}
+
 func TestOutgoingTLS(t *testing.T) {
 	t.Parallel()
 	ts := httptest.NewTLSServer(&helloHandler{})
@@ -1325,7 +1376,7 @@ func TestOutgoingTLSInsecureSkipVerify(t *testing.T) {
 func TestOutgoingTLSInvalidCertificate(t *testing.T) {
 	t.Parallel()
 	ts := httptest.NewTLSServer(&helloHandler{})
-	ts.Config.ErrorLog = log.New(ioutil.Discard, "", 0)
+	ts.Config.ErrorLog = log.New(io.Discard, "", 0)
 	defer ts.Close()
 
 	logger := &Logger{
@@ -1374,7 +1425,7 @@ func TestOutgoingTLSBadClientCertificate(t *testing.T) {
 	}
 	var buf bytes.Buffer
 	logger.SetOutput(&buf)
-	ts.Config.ErrorLog = log.New(ioutil.Discard, "", 0)
+	ts.Config.ErrorLog = log.New(io.Discard, "", 0)
 	client := ts.Client()
 	cert, err := tls.LoadX509KeyPair("testdata/cert-client.pem", "testdata/key-client.pem")
 	if err != nil {
@@ -1396,22 +1447,23 @@ func TestOutgoingTLSBadClientCertificate(t *testing.T) {
 	}
 	req.Host = "example.com" // overriding the Host header to send
 	req.Header.Add("User-Agent", "Robot/0.1 crawler@example.com")
-	if _, err = client.Do(req); err == nil || !strings.Contains(err.Error(), "bad certificate") {
+	var ue = &url.Error{}
+	if _, err = client.Do(req); err == nil || !errors.As(err, &ue) {
 		t.Errorf("got: %v, expected bad certificate error message", err)
 	}
-	want := fmt.Sprintf(golden(t.Name()), ts.URL)
-	if got := buf.String(); got != want {
+	want := fmt.Sprintf(golden(t.Name()), ts.URL, strings.SplitAfter(err.Error(), "remote error: tls: ")[1])
+	if got := buf.String(); !strings.Contains(got, want) {
 		t.Errorf("logged HTTP request %s; want %s", got, want)
 	}
 }
 
 func TestOutgoingHTTP2MutualTLS(t *testing.T) {
 	t.Parallel()
-	caCert, err := ioutil.ReadFile("testdata/cert.pem")
+	caCert, err := os.ReadFile("testdata/cert.pem")
 	if err != nil {
 		panic(err)
 	}
-	clientCert, err := ioutil.ReadFile("testdata/cert-client.pem")
+	clientCert, err := os.ReadFile("testdata/cert-client.pem")
 	if err != nil {
 		panic(err)
 	}
@@ -1505,11 +1557,11 @@ func TestOutgoingHTTP2MutualTLS(t *testing.T) {
 
 func TestOutgoingHTTP2MutualTLSNoSafetyLogging(t *testing.T) {
 	t.Parallel()
-	caCert, err := ioutil.ReadFile("testdata/cert.pem")
+	caCert, err := os.ReadFile("testdata/cert.pem")
 	if err != nil {
 		panic(err)
 	}
-	clientCert, err := ioutil.ReadFile("testdata/cert-client.pem")
+	clientCert, err := os.ReadFile("testdata/cert-client.pem")
 	if err != nil {
 		panic(err)
 	}
